@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: esqueleto
 version: 2.4.3
-id: esqueleto-2.4.3-31e08b67f9a71a3c46b81c06d317b814
-key: esque_20bDpgY8dV2G4wxcfx1u6j
+id: esqueleto-2.4.3-8309543a30deb448f73bc0bf29668ea0
+key: esque_8qVr5drVxW3BTaKmJzxajl
 license: BSD3
 copyright: (c) 2012-2015 Felipe Almeida Lessa
 maintainer: felipe.lessa@gmail.com
@@ -52,15 +52,15 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/esqueleto-2.4.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/esqueleto-2.4.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/esqueleto-2.4.3
-hs-libraries: HSesqueleto-2.4.3-20bDpgY8dV2G4wxcfx1u6j
+hs-libraries: HSesqueleto-2.4.3-8qVr5drVxW3BTaKmJzxajl
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.2-e9736ac2851958c9940f374454cdc4fe
-    monad-logger-0.3.18-1a8cc90bb0cf2afc03da9e875eb23203
-    persistent-2.2.4-bd2986a850822d0f7f277144476772ce
-    resourcet-1.1.7.2-b95e5d14f30eaa21587bc62eeb9aed0c
+    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
+    monad-logger-0.3.18-7704b739a8ba950a4b62906c3ab56228
+    persistent-2.2.4.1-550ce3a441e5dfee4f5236d6597d598b
+    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
     tagged-0.8.3-aa128de4449752177a05765fb0ce3959
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
